@@ -81,7 +81,7 @@ MainWindowPrivate::MainWindowPrivate(MainWindow *w, Controller* controller)
     action = new KAction(i18n("Focus Editor"), this);
     action->setShortcuts(QList<QKeySequence>() << (Qt::META | Qt::CTRL | Qt::Key_E) << Qt::META + Qt::Key_C);
     connect(action, SIGNAL(triggered(bool)), this, SLOT(focusEditor()));
-    m_mainWindow->actionCollection()->addAction("focus_editor", action);
+    ac->addAction("focus_editor", action);
 
     action = new KAction(i18n("Hide/Restore Docks"), this);
     action->setShortcut(Qt::META | Qt::CTRL | Qt::Key_H);
@@ -211,6 +211,7 @@ Area::WalkerMode MainWindowPrivate::ViewCreator::operator() (AreaIndex *index)
         else
         {
             parent = d->m_indexSplitters[index->parent()];
+            Q_ASSERT(parent);
             kDebug() << "adding new splitter to" << parent;
             splitter = new QSplitter(parent);
             d->m_indexSplitters[index] = splitter;
@@ -229,6 +230,10 @@ Area::WalkerMode MainWindowPrivate::ViewCreator::operator() (AreaIndex *index)
             //we need to create view container
             container = new Container(splitter);
             connect(container, SIGNAL(activateView(Sublime::View*)), d->m_mainWindow, SLOT(activateView(Sublime::View*)));
+            connect(container, SIGNAL(tabContextMenuRequested(Sublime::View*,KMenu*)),
+                    d->m_mainWindow, SLOT(tabContextMenuRequested(Sublime::View*,KMenu*)));
+            connect(container, SIGNAL(tabToolTipRequested(Sublime::View*,QPoint)),
+                    d->m_mainWindow, SLOT(tabToolTipRequested(Sublime::View*,QPoint)));
             connect(container, SIGNAL(closeRequest(QWidget*)),
                     d, SLOT(widgetCloseRequest(QWidget*)));
             splitter->addWidget(container);
@@ -255,8 +260,10 @@ Area::WalkerMode MainWindowPrivate::ViewCreator::operator() (AreaIndex *index)
 
 void MainWindowPrivate::reconstruct()
 {
-    if(m_leftTabbarCornerWidget)
+    if(m_leftTabbarCornerWidget) {
+        m_leftTabbarCornerWidget->hide();
         m_leftTabbarCornerWidget->setParent(0);
+    }
     
     IdealToolViewCreator toolViewCreator(this);
     area->walkToolViews(toolViewCreator, Sublime::AllPositions);
@@ -342,6 +349,9 @@ void MainWindowPrivate::recreateCentralWidget()
             SIGNAL(widgetResized(IdealMainLayout::Role, int)),
             this,
             SLOT(widgetResized(IdealMainLayout::Role, int)));
+
+    connect(idealMainWidget, SIGNAL(dockBarContextMenuRequested(Qt::DockWidgetArea, const QPoint&)),
+            m_mainWindow, SLOT(dockBarContextMenuRequested(Qt::DockWidgetArea, const QPoint&)));
 }
 
 void MainWindowPrivate::
@@ -359,8 +369,10 @@ slotDockShown(Sublime::View* view, Sublime::Position pos, bool shown)
 
 void MainWindowPrivate::viewAdded(Sublime::AreaIndex *index, Sublime::View *view)
 {
-    if(m_leftTabbarCornerWidget)
+    if(m_leftTabbarCornerWidget) {
+        m_leftTabbarCornerWidget->hide();
         m_leftTabbarCornerWidget->setParent(0);
+    }
     
     ViewCreator viewCreator(this);
     QSplitter *splitter = m_indexSplitters[index];
@@ -424,8 +436,10 @@ void MainWindowPrivate::aboutToRemoveView(Sublime::AreaIndex *index, Sublime::Vi
     }
     else
     {
-        if(m_leftTabbarCornerWidget)
+        if(m_leftTabbarCornerWidget) {
+            m_leftTabbarCornerWidget->hide();
             m_leftTabbarCornerWidget->setParent(0);
+        }
         
         // We've about to remove the last view of this container.  It will
         // be empty, so have to delete it, as well.
@@ -507,7 +521,7 @@ void MainWindowPrivate::aboutToRemoveView(Sublime::AreaIndex *index, Sublime::Vi
     m_mainWindow->setActiveView(0L);
 }
 
-void MainWindowPrivate::toolViewAdded(Sublime::View */*toolView*/, Sublime::Position position)
+void MainWindowPrivate::toolViewAdded(Sublime::View* /*toolView*/, Sublime::Position position)
 {
     IdealToolViewCreator toolViewCreator(this);
     area->walkToolViews(toolViewCreator, position);
@@ -585,12 +599,9 @@ void MainWindowPrivate::widgetCloseRequest(QWidget* widget)
 }
 
 void MainWindowPrivate::toggleArea ( int index ) {
-#if QT_VERSION >= 0x040500
     m_mainWindow->controller()->showArea(areaSwitcher->tabBar->areaId(index), m_mainWindow);
-#endif
 }
 
-#if QT_VERSION >= 0x040500
 void AreaTabBar::paintEvent ( QPaintEvent* ev ) {
     QTabBar::paintEvent(ev);
     if ( currentIndex() != -1 ) {
@@ -750,7 +761,6 @@ AreaTabButton::AreaTabButton ( QString text, QIcon icon, uint iconSize, QWidget*
     layout->addWidget ( iconLabel );
     layout->setMargin ( 0 );
 }
-#endif
 
 void MainWindowPrivate::setTabBarLeftCornerWidget(QWidget* widget)
 {
